@@ -1,8 +1,8 @@
 from __future__ import print_function
 from __future__ import unicode_literals
 
+import os.path
 import re
-from collections import OrderedDict
 
 import six
 from aspy.yaml import ordered_dump
@@ -13,11 +13,11 @@ import pre_commit.constants as C
 from pre_commit import output
 from pre_commit.clientlib import CONFIG_SCHEMA
 from pre_commit.clientlib import InvalidManifestError
-from pre_commit.clientlib import is_local_repo
-from pre_commit.clientlib import is_meta_repo
 from pre_commit.clientlib import load_config
+from pre_commit.clientlib import load_manifest
+from pre_commit.clientlib import LOCAL
+from pre_commit.clientlib import META
 from pre_commit.commands.migrate_config import migrate_config
-from pre_commit.repository import Repository
 from pre_commit.util import CalledProcessError
 from pre_commit.util import cmd_output
 
@@ -52,24 +52,24 @@ def _update_repo(repo_config, store, tags_only):
     if rev == repo_config['rev']:
         return repo_config
 
-    # Construct a new config with the head rev
-    new_config = OrderedDict(repo_config)
-    new_config['rev'] = rev
-
     try:
-        new_hooks = Repository.create(new_config, store).manifest_hooks
+        path = store.clone(repo_config['repo'], rev)
+        manifest = load_manifest(os.path.join(path, C.MANIFEST_FILE))
     except InvalidManifestError as e:
         raise RepositoryCannotBeUpdatedError(six.text_type(e))
 
     # See if any of our hooks were deleted with the new commits
     hooks = {hook['id'] for hook in repo_config['hooks']}
-    hooks_missing = hooks - set(new_hooks)
+    hooks_missing = hooks - {hook['id'] for hook in manifest}
     if hooks_missing:
         raise RepositoryCannotBeUpdatedError(
             'Cannot update because the tip of master is missing these hooks:\n'
             '{}'.format(', '.join(sorted(hooks_missing))),
         )
 
+    # Construct a new config with the head rev
+    new_config = repo_config.copy()
+    new_config['rev'] = rev
     return new_config
 
 
@@ -112,19 +112,18 @@ def _write_new_config_file(path, output):
         f.write(to_write)
 
 
-def autoupdate(runner, store, tags_only, repos=()):
+def autoupdate(config_file, store, tags_only, repos=()):
     """Auto-update the pre-commit config to the latest versions of repos."""
-    migrate_config(runner, quiet=True)
+    migrate_config(config_file, quiet=True)
     retv = 0
     output_repos = []
     changed = False
 
-    input_config = load_config(runner.config_file_path)
+    input_config = load_config(config_file)
 
     for repo_config in input_config['repos']:
         if (
-            is_local_repo(repo_config) or
-            is_meta_repo(repo_config) or
+            repo_config['repo'] in {LOCAL, META} or
             # Skip updating any repo_configs that aren't for the specified repo
             repos and repo_config['repo'] not in repos
         ):
@@ -152,6 +151,6 @@ def autoupdate(runner, store, tags_only, repos=()):
     if changed:
         output_config = input_config.copy()
         output_config['repos'] = output_repos
-        _write_new_config_file(runner.config_file_path, output_config)
+        _write_new_config_file(config_file, output_config)
 
     return retv
